==> easyviper.extended.behaviours.package.debug-1.0.1-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/api/DebugBehaviour.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api;

import javax.xml.namespace.QName;

import org.objectweb.fractal.fraclet.annotations.Interface;

import com.ebmwebsourcing.easyviper.core.service.extended.behaviour.api.ExtendedBehaviour;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@Interface(name = "service")
public interface DebugBehaviour extends ExtendedBehaviour {

	public final static QName name = new QName(ExtendedBehaviour.name.getNamespaceURI(), "Debug");
	
	boolean isActivate();
	
	void setActivate(boolean activate);
	
}

==> easyviper.extended.behaviours.package.debug-1.1-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/api/DebugBehaviour.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api;

import javax.xml.namespace.QName;

import org.objectweb.fractal.fraclet.annotations.Interface;

import com.ebmwebsourcing.easyviper.core.service.extended.behaviour.api.ExtendedBehaviour;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@Interface(name = "service")
public interface DebugBehaviour extends ExtendedBehaviour {

	QName name = new QName(ExtendedBehaviour.name.getNamespaceURI(), "Debug");
	
	boolean isActivate();
	
	void setActivate(boolean activate);
	
}
